@@ -45,6 +45,8 @@ class Decoder(base.Model):
             file_name=None,
             folder=load.TFBOX,
             nb_classes=None,
+            from_logits=None,
+            add_classifier=False,
             name=NAME,
             named_layers=True,
             noisy=True):
@@ -85,11 +87,12 @@ class Decoder(base.Model):
                 self._refinement(r,index=i) for i,r in enumerate(refinements) ]
         else:
             self.refinements=None
-        if nb_classes:
+        if add_classifier and nb_classes:
             self.set_classifier(
                 nb_classes,
                 config.get('classifier'),
-                folder=folder)
+                folder=folder,
+                from_logits=from_logits)
 
 
     def set_output(self,like):
@@ -154,7 +157,9 @@ class Decoder(base.Model):
 
 
     def _output_conv(self,config,nb_classes):
-        if config is None:
+        if isinstance(config,dict):
+            config['filters']=config.get('filters') or nb_classes
+        elif config is None:
             config=nb_classes
         return self._configurable_block(
             config,
